# Create a new SSH key
resource "digitalocean_ssh_key" "default" {
  name       = "Terraform Example"
  public_key = file("~/.ssh/id_rsa.pub")
}

# Create a new Web Droplet in the nyc2 region
resource "digitalocean_droplet" "web" {
  image    = "ubuntu-22-04-x64"
  name     = "wireguard"
  region   = "nyc1"
  size     = "s-2vcpu-4gb"
  ssh_keys = [digitalocean_ssh_key.default.fingerprint]
  user_data = file("setup.sh")
  connection {
    host = digitalocean_droplet.web.ipv4_address
    type = "ssh"
    user = "root"
    private_key = "${file("~/.ssh/id_rsa.pem")}"
  }

  provisioner "remote-exec" {
    inline = [ "cat /root/wireguard-config/client-config.conf" ]
  }
}

output "droplet_output" {
  value = digitalocean_droplet.web.ipv4_address
}